Module molecular_simulations.analysis.analyzer
==============================================

Classes
-------

`SimulationAnalyzer(path: str, system: str, data_path: str = 'sim_data', stride: int = 100)`
:   

    ### Instance variables

    `length`
    :

    ### Methods

    `analyze(self)`
    :

    `binderRMSD(self)`
    :

    `build_universe(self)`
    :

    `clean(self)`
    :

    `comDist(self)`
    :

    `contactProb(self)`
    :

    `deltaCoM(self)`
    :

    `get_output(self, d, suffix: str | None = None)`
    :

    `nativeContacts(self)`
    :

    `rog(self)`
    :